<?php
namespace Zeedhi\DataMining\Common\Util;

use Moment\Moment;
use Cron\CronExpression;

class Period {

    const UNIT_DAY   = "day";
    const UNIT_WEEK  = "week";
    const UNIT_MONTH = "month";
    const UNIT_YEAR  = "year";

    const DATE_FORMAT = 'd/m/Y';

    /**
     * @param string $periodStart
     * @param string $periodEnd
     * @return Moment[]
     */
    public static function convertStringToMoment($periodStart, $periodEnd, $format = self::DATE_FORMAT) {
        $dateTimeStart = \DateTime::createFromFormat($format, $periodStart);
        $dateTimeEnd = \DateTime::createFromFormat($format, $periodEnd);
        $start = self::convertDateTimeToMoment($dateTimeStart);
        $start->startOf(self::UNIT_DAY);
        $end = self::convertDateTimeToMoment($dateTimeEnd);
        $end->endOf(self::UNIT_DAY);
        return array($start, $end);
    }

    /**
     * @param \DateTime $dateTime
     * @return Moment
     */
    public static function convertDateTimeToMoment(\DateTime $dateTime) {
        $moment = new Moment();
        $moment->setYear($dateTime->format('Y'));
        $moment->setMonth($dateTime->format('m'));
        $moment->setDay($dateTime->format('d'));
        return $moment;
    }

    /**
     * Return formatted period - d/m/Y to d/m/Y
     * @param $period
     * @return array
     */
    public static function decodeFormatted($period) {
        return self::formatInterval(self::decode($period));
    }

    /**
     * @param Moment[] $interval
     * @return array
     */
    public static function formatInterval(array $interval) {
        return array (
            $interval[0]->format(self::DATE_FORMAT),
            $interval[1]->format(self::DATE_FORMAT)
        );
    }
}